@@ -1,5 +1,19 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+#
+# PyCallBlocker for Maemo 5.
+#
+# Author: V@s3K
+# Web: http://vas3k.ru/work/pycallblocker
+# Date: 2010.02.27
+#
+# File: callblocker.py
+# Version: 1.2
+# 
+# Special thanks to: 
+#    http://maemos.ru
+#    http://maemocentral.com/2010/02/22/how-to-block-unwanted-callers-on-the-n900/
+#
 
 blocklistFile = '/home/user/MyDocs/BlockedCallers.txt'
 daemonFile = '/opt/pycallblocker/callblocker-daemon.py'
@@ -17,7 +31,6 @@ class PyCallBlock(QtGui.QWidget):
         self.setWindowTitle("PyCallBlocker")
         
         self.number_list = QtGui.QListWidget(self)
-        self.restart_button = QtGui.QPushButton("Save and restart daemon", self)
         self.new_button = QtGui.QPushButton("New number", self)
         self.del_button = QtGui.QPushButton("Delete number", self)
         
@@ -28,15 +41,12 @@ class PyCallBlock(QtGui.QWidget):
         self.butt_layout.addWidget(self.new_button)
         self.butt_layout.addWidget(self.del_button)
         self.layout.addLayout(self.butt_layout)
-     
-        self.layout.addWidget(self.restart_button)
         
         self.connect(self.new_button, SIGNAL('clicked()'), self.slotadd)
-        self.connect(self.restart_button, SIGNAL('clicked()'), self.restartDaemon)
         self.connect(self.del_button, SIGNAL('clicked()'), self.slotdel)
-        #self.connect(self.number_list, SIGNAL("itemClicked()"), self, SLOT("slotdel(PyQt_PyObject)"))
         
         self.loadList()
+        self.restartDaemon()
         
     def slotadd(self):
         text, ok = QtGui.QInputDialog.getText(self, "Enter new block number", "Phone:")
@@ -45,6 +55,7 @@ class PyCallBlock(QtGui.QWidget):
             blFile.write(text + "\n")
             blFile.close()
         self.loadList()
+        self.restartDaemon()
     
     def slotdel(self):
         row = self.number_list.currentRow()
@@ -59,6 +70,7 @@ class PyCallBlock(QtGui.QWidget):
             if ok:
                 self.deleteFromList(text)
             self.loadList()
+            self.restartDaemon()
     
     def deleteFromList(self, text):
         blFile = open(blocklistFile, 'r')
@@ -93,7 +105,7 @@ class PyCallBlock(QtGui.QWidget):
         try:
             pdFile = open(pidFile, 'r+')
             pid = pdFile.readline().strip()
-            subprocess.Popen("kill -9 " + str(int(pid) + 1), shell=True)
+            subprocess.Popen("kill -9 " + str(pid), shell=True)
             pdFile.close()
         except:
             pass
@@ -101,10 +113,8 @@ class PyCallBlock(QtGui.QWidget):
         proc = subprocess.Popen("python2.5 " + daemonFile + " &", shell=True)
         
         pdFile = open(pidFile, 'w+')
-        pdFile.write(str(proc.pid))
+        pdFile.write(str(proc.pid + 1))
         pdFile.close()
-        #os.popen("killall -9 python2.5")
-        #os.popen("python2.5 " + daemonFile + " &")
 
 # Execution
 app = QtGui.QApplication(sys.argv)
